<a id="markdown-текучие-fluent-утверждения" name="текучие-fluent-утверждения"></a>
# Текучие-(fluent)-утверждения

<!-- TOC -->

- [Текучие-(fluent)-утверждения](#текучие-fluent-утверждения)
    - [Введение](#введение)
    - [Обращение к плагину (пример)](#обращение-к-плагину-пример)
        - [Из кода шагов (BDD), запускаемых через `bddRunner`](#из-кода-шагов-bdd-запускаемых-через-bddrunner)
        - [Из кода тестов (TDD), запускаемых через `xddTestRunner`](#из-кода-тестов-tdd-запускаемых-через-xddtestrunner)
    - [Публичный интерфейс](#публичный-интерфейс)
    - [Примеры использования](#примеры-использования)
        - [Пример немного сложнее](#пример-немного-сложнее)

<!-- /TOC -->

<a id="markdown-введение" name="введение"></a>
## Введение

Рекомендуем почитать статью автора реализации этого вида утверждений
- [Юнит-тесты, BDD и сила текучих утверждений (fluent assertions) в 1С](http://habrahabr.ru/post/260013/)
  - 5 минут на прочтение

<a id="markdown-обращение-к-плагину-пример" name="обращение-к-плагину-пример"></a>
## Обращение к плагину (пример)

<a id="markdown-из-кода-шагов-bdd-запускаемых-через-bddrunner" name="из-кода-шагов-bdd-запускаемых-через-bddrunner"></a>
### Из кода шагов (BDD), запускаемых через `bddRunner`

```bsl
Процедура МойШаг(...) Экспорт
  Ожидаем = Ванесса.Плагин("УтвержденияBDD");
  Ожидаем.Что(НекийМассив.Количество(), "Ожидали 9 элементов, но это не так")
      .ЭтоНе()
      .Равно(9);
КонецПроцедуры
```

<a id="markdown-из-кода-тестов-tdd-запускаемых-через-xddtestrunner" name="из-кода-тестов-tdd-запускаемых-через-xddtestrunner"></a>
### Из кода тестов (TDD), запускаемых через `xddTestRunner`

```bsl
Перем КонтекстЯдра;
Перем Ожидаем;

Процедура Инициализация(КонтекстЯдраПараметр) Экспорт
	КонтекстЯдра = КонтекстЯдраПараметр;
	Ожидаем = КонтекстЯдра.Плагин("УтвержденияBDD");
КонецПроцедуры

Процедура ТестДолжен() Экспорт
  Ожидаем.Что(НекийМассив.Количество(), "Ожидали 9 элементов, но это не так")
      .ЭтоНе()
      .Равно(9);
КонецПроцедуры
```

<a id="markdown-публичный-интерфейс" name="публичный-интерфейс"></a>
## Публичный интерфейс

- `Что(ПроверяемоеЗначение, Сообщение = "")` — сохраняет в контексте внешней обработки проверяемое значение и дополнительное сообщение для исключений выбрасываемых утверждениями.

- `Не_()` — отрицает любое утверждение следующее по цепи.

- `ЭтоИстина()` — утверждает, что проверяемое значение является Истиной.

- `ЭтоЛожь()` — утверждает, что проверяемое значение является Ложью.

- `Равно(ОжидаемоеЗначение)` — утверждает, что проверяемое значение равно ожидаемому.

- `Больше(МеньшееЗначение)` — утверждает, что проверяемое значение больше, чем переданное в утверждение.

- `БольшеИлиРавно(МеньшееИлиРавноеЗначение)` / `Минимум(МинимальноеЗначение)` — утверждает, что проверяемое значение больше или равно переданному в утверждение.

- `МеньшеИлиРавно(БольшееИлиРавноеЗначение)` / `Максимум(МаксимальноеЗначение)` — утверждает, что проверяемое значение меньше или равно переданному в утверждение.

- `Меньше(БольшееЗначение)` — утверждает, что проверяемое значение меньше, чем переданное в утверждение.

- `Заполнено()` — утверждает, что проверяемое значение отличается от значения по умолчанию того же типа.

- `Существует()` — утверждает, что проверяемое значение не Null и не Неопределено.

- `ЭтоНеопределено()` — утверждает, что проверяемое значение это Неопределено.

- `ЭтоNull()` — утверждает, что проверяемое значение это Null.

- `ИмеетТип(Тип)` — утверждает, что проверяемое значение имеет переданный в утверждение тип или имя типа.

- `Между(НачальноеЗначение, КонечноеЗначение)` — утверждает, что проверяемое значение находится между переданными в утверждение значениями.

- `Содержит(ИскомоеЗначение)` — утверждает, что проверяемое значение содержит переданное в утверждение. Применяется для строк и коллекций.

- `ИмеетДлину(ОжидаемаяДлина)` — утверджает, что проверяемое значение имеет длину переданную в утверждение. Применяется для строк и коллекций.

<a id="markdown-примеры-использования" name="примеры-использования"></a>
## Примеры использования

```bsl
Ожидаем.Что(1 > 0).ЭтоИстина();
Ожидаем.Что(13 = 2).Не_().ЭтоИстина();
Ожидаем.Что(5 = 7).ЭтоЛожь();
Ожидаем.Что(5).Равно(5);
Ожидаем.Что(4).Больше(2);
Ожидаем.Что(7).БольшеИлиРавно(7);
Ожидаем.Что(НекийМассив.Количество()).Минимум(9);
Ожидаем.Что(90).МеньшеИлиРавно(100);
Ожидаем.Что(СтрДлина(НекаяСтрока)).Максимум(90);
Ожидаем.Что(55).Меньше(56);
Ожидаем.Что(1).Заполнено();
Ожидаем.Что(Новый Массив).Существует();
Ожидаем.Что(Неопределено).ЭтоНеопределено();
Ожидаем.Что(ВыборкаИзБД.НекоеПоле).ЭтоNull();
Ожидаем.Что("").ИмеетТип("Строка");
Ожидаем.Что(7).Между(1, 10);
Ожидаем.Что("Некая строка").Содержит("стр");
Ожидаем.Что("Некая строка").ИмеетДлину(12);
```

<a id="markdown-пример-немного-сложнее" name="пример-немного-сложнее"></a>
### Пример немного сложнее

```bsl
Ожидаем.Что("Некая строка")
		.Существует()
		.Не_().ИмеетТип("Число")
		.ИмеетДлину(12)
		.Не_().Содержит("!!!");
```
